@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -27,6 +27,7 @@
 #include <gcp/document.h>
 #include <gcp/theme.h>
 #include <gcp/view.h>
+#include <gcp/widgetdata.h>
 #include <glib/gi18n-lib.h>
 #include <cstring>
 
@@ -46,7 +47,7 @@ GtkWindow* GOGcpApplication::GetWindow()
 	return NULL;
 }
 
-void GOGcpApplication::ToggleMenu (const string& menuname, bool active)
+void GOGcpApplication::ToggleMenu (G_GNUC_UNUSED const string& menuname, G_GNUC_UNUSED bool active)
 {
 }
 
@@ -98,7 +99,7 @@ GtkWindow * GOGcpApplication::EditDocument (GOGChemUtilsComponent *gogcu)
 	}
 }
 
-bool GOGcpApplication::GetData (GOGChemUtilsComponent *gogcu, gpointer *data, int *length, void (**clearfunc) (gpointer), gpointer *user_data)
+bool GOGcpApplication::GetData (GOGChemUtilsComponent *gogcu, gpointer *data, int *length, void (**clearfunc) (gpointer), G_GNUC_UNUSED gpointer *user_data)
 {
 	gcp::Document *doc = static_cast <gcp::Document *> (gogcu->document);
 	bool result = false;
@@ -132,7 +133,6 @@ bool GOGcpApplication::GetData (GOGChemUtilsComponent *gogcu, gpointer *data, in
 		if (xml)
 			xmlFreeDoc (xml);
 		xml = NULL;
-//		Error (SAVE);
 		result = false;
 	}
 	setlocale (LC_NUMERIC, old_num_locale);
@@ -156,8 +156,7 @@ void GOGcpApplication::UpdateBounds (GOGChemUtilsComponent *gogcu)
 	gcp::Document *doc = static_cast <gcp::Document *> (gogcu->document);
 	gcp::Theme *pTheme = doc->GetTheme ();
 	GtkWidget *w = doc->GetWidget ();
-	gnome_canvas_update_now (GNOME_CANVAS (w));
-	ArtDRect rect;
+	gccv::Rect rect;
 	gcp::WidgetData *pData = (gcp::WidgetData*) g_object_get_data (G_OBJECT (w), "data");
 	pData->GetObjectBounds (doc, &rect);
 	double y = doc->GetYAlign ();
