@@ -60,7 +60,7 @@ Atom::Atom ():
 	m_HPosStyle (AUTO_HPOS)
 {
 	m_Valence = -1; //unspecified
-	m_nlp = 0;
+	m_nlp = m_nlu = 0;
 	m_nH = 0;
 	m_HPos = GetBestSide();
 	m_ChargeAuto = false;
@@ -108,8 +108,7 @@ Atom::Atom (int Z, double x, double y, double z):
 {
 	m_ChargeAuto = false;
 	m_HPos = GetBestSide ();
-	m_nlp = 0;
-	SetZ(Z);
+	m_nlp = m_nlu = 0;
 	m_ascent = 0;
 	m_CHeight = 0.;
 	m_Changed = 0;
@@ -124,6 +123,7 @@ Atom::Atom (int Z, double x, double y, double z):
 	m_SWidth = 0.;
 	m_ChargeItem = NULL;
 	m_ShowCharge = true;
+	SetZ(Z);
 }
 
 Atom::Atom (OBAtom* atom):
@@ -135,8 +135,7 @@ Atom::Atom (OBAtom* atom):
 	m_x = atom->GetX ();
 	m_y = - atom->GetY ();
 	m_z = atom->GetZ ();
-	m_nlp = 0;
-	SetZ (atom->GetAtomicNum ());
+	m_nlp = m_nlu = 0;
 	gchar* Id = g_strdup_printf ("a%d", atom->GetIdx());
 	SetId (Id);
 	g_free (Id);
@@ -156,6 +155,7 @@ Atom::Atom (OBAtom* atom):
 	m_SWidth = 0.;
 	m_ChargeItem = NULL;
 	m_ShowCharge = true;
+	SetZ (atom->GetAtomicNum ());
 }
 
 void Atom::SetZ (int Z)
@@ -210,7 +210,7 @@ int Atom::GetTotalBondsNumber () const
 void Atom::AddBond (gcu::Bond* pBond)
 {
 	gcu::Atom::AddBond (pBond);
-	Update ();
+	m_Changed = true;
 }
 
 void Atom::RemoveBond (gcu::Bond* pBond)
@@ -300,9 +300,6 @@ void Atom::Update ()
 			m_ChargeAuto = true;
 		}
 	}
-	Document *pDoc = (Document *) GetDocument ();
-	if (pDoc && pDoc->GetView ())
-		m_Changed = pDoc->GetView ()->GetNbWidgets ();
 	m_AvailPosCached = false;
 	map<gcu::Atom*, gcu::Bond*>::iterator j = m_Bonds.begin(), jend = m_Bonds.end ();
 	if (nbonds && GetZ () == 6) {
@@ -335,10 +332,8 @@ void Atom::Update ()
 					DrawCircle = true;
 			}
 		}
-		if (DrawCircle != m_DrawCircle) {
+		if (DrawCircle != m_DrawCircle)
 			m_DrawCircle = DrawCircle;
-			m_Changed = true;
-		}
 	}
 	// Update all double bonds
 	for (j = m_Bonds.begin(); j != jend; j++)
@@ -725,23 +720,28 @@ double Atom::GetYAlign ()
 bool Atom::HasImplicitElectronPairs ()
 {
 	map<string, Object*>::iterator i;
-	Electron* electron = (Electron*) GetFirstChild (i);
+	Object *obj = GetFirstChild (i);
+	Electron* electron = NULL;
 	if (m_Valence > 0) {
 		int nexplp = 0; //nexplp is the number of explicit lone pairs
-		while (electron) { 
-			if (electron->IsPair ())
+		while (obj) {
+			electron = dynamic_cast <Electron *> (obj);
+			if (electron && electron->IsPair ())
 				nexplp++;
-			electron = (Electron*) GetNextChild (i);
+			obj = GetNextChild (i);
 		}
 		return (m_nlp > nexplp);
 	}
 	unsigned nel = 0;
-	while (electron){ 
-		if (electron->IsPair ())
-			nel += 2;
-		else
-			nel++;
-		electron = (Electron*) GetNextChild (i);
+	while (electron) { 
+		electron = dynamic_cast <Electron *> (obj);
+		if (electron) {
+			if (electron->IsPair ())
+				nel += 2;
+			else
+				nel++;
+		}
+		obj = GetNextChild (i);
 	}
 	nel += GetTotalBondsNumber ();
 	int nocc = GetChildrenNumber () + GetTotalBondsNumber ();
@@ -780,7 +780,7 @@ bool Atom::GetRelativePosition (double angle, double& x, double& y)
 		double limit = atan (m_height / m_width) * 180. / M_PI;
 		if (angle < limit) {
 			x = m_width / 2.;
-			y = m_width / 2. * t;
+			y = -m_width / 2. * t;
 		} else if (angle < 180. - limit) {
 			if (!isnan (t))
 				x = m_height / 2. / t;
@@ -1302,6 +1302,10 @@ void Atom::AddItem ()
 {
 	if (m_Item)
 		return;
+	if (m_Changed) {
+		Update ();
+		m_Changed = true;
+	}
 	Document *doc = static_cast <Document*> (GetDocument ());
 	View *view = doc->GetView ();
 	Theme *theme = doc->GetTheme ();
@@ -1429,19 +1433,45 @@ void Atom::AddItem ()
 bool Atom::HasAvailableElectrons (bool paired)
 {
 	map<string, Object*>::iterator i;
-	Electron* electron = static_cast <Electron *> (GetFirstChild (i));
+	Object *obj = GetFirstChild (i);
+	Electron *electron = NULL;
+	while (obj) {
+		if ((electron = dynamic_cast <Electron *> (obj)))
+			break;
+			obj = GetNextChild (i);
+	}
 	if (paired) {
 		if (m_nlp)
 			return true;
-		while (electron) { 
-			if (electron->IsPair ())
+		while (obj) { 
+			if (electron && electron->IsPair ())
 				return true;
-			electron = static_cast <Electron *> (GetNextChild (i));
+			obj = GetNextChild (i);
+			electron = dynamic_cast <Electron *> (obj);
 		}
 	} else {
-		return (electron) || (m_nlp) || (m_nlu); // TODO: take curved arrows into account
+		return electron || m_nlp || m_nlu; // TODO: take curved arrows into account
 	}
 	return false;
 }
 
+Bond *Atom::GetBondAtAngle (double angle)
+{
+	Bond *res = NULL, *bond;
+	double a1, a0 = 2 * M_PI;// something larger that anything we can get
+	std::map <gcu::Atom *, gcu::Bond *>::iterator it;
+	for (bond = static_cast <gcp::Bond *> (GetFirstBond (it)); bond; bond = static_cast <gcp::Bond *> (GetNextBond (it))) {
+		a1 = bond->GetAngle2DRad (this);
+		a1 -= angle;
+		a1 = fabs (a1);
+		if (a1 > M_PI)
+			a1 = 2 * M_PI - a1;
+		if (a1 < a0) {
+			a0 = a1;
+			res = bond;
+		}
+	}
+	return res;
+}
+
 }	//	namespace gcp
