@@ -25,9 +25,11 @@
 #ifndef GCHEMPAINT_BOND_H
 #define GCHEMPAINT_BOND_H
 
+/*!\file*/
+
+#include <gccv/item-client.h>
 #include <gcu/bond.h>
 #include <list>
-#include <libgnomecanvas/gnome-canvas-path-def.h>
 
 namespace gcp {
 
@@ -70,7 +72,7 @@ class WidgetData;
 This class is used to represent bonds.
 */
 
-class Bond: public gcu::Bond
+class Bond: public gcu::Bond, public gccv::ItemClient
 {
 public:
 /*!
@@ -159,12 +161,6 @@ Loads properties specific to GChemPaint bonds.
 */
 	bool LoadNode (xmlNodePtr node);
 /*!
-@param w the GtkWidget inside which the bond is displayed.
-
-Used to update the representation of the bond in the widget.
-*/
-	void Update (GtkWidget* w) const;
-/*!
 @param x the x component of the transation vector.
 @param y the y component of the transation vector.
 @param z the z component of the transation vector.
@@ -210,20 +206,21 @@ bond order is set to 1.
 */
 	void IncOrder (int n = 1);
 /*!
-@param w the GtkWidget inside which the bond is displayed.
+Used to add a representation of the bond in the view.
+*/
+	void AddItem ();
+/*!
+Used to update the representation of the bond in the view.
+*/
+	void UpdateItem ();
+/*!
 @param state the selection state of the bond.
 
 Used to set the selection state of the bond inside the widget.
 The values of state might be gcp::SelStateUnselected, gcp::SelStateSelected,
 gcp::SelStateUpdating, or gcp::SelStateErasing.
 */
-	void SetSelected (GtkWidget* w, int state);
-/*!
-@param w the GtkWidget inside which the bond will be displayed.
-
-Used to add a representation of the bond in the widget.
-*/
-	void Add (GtkWidget* w) const;
+	void SetSelected (int state);
 /*!
 Used to retrieve the y coordinate for alignment.
 @return y coordinate of the bond center.
@@ -255,6 +252,13 @@ Brings the bond to front. It has an effect only for crossing bonds.
 */
 	void BringToFront ();
 /*!
+@param property the identity of the property as defined in objprops.h.
+
+Used by the gcu::Loader mechanism to retrieve properties of bonds.
+@return the value of the property as a string.
+*/
+	std::string GetProperty (unsigned property) const;
+/*!
 @param property the property id as defined in objprops.h
 @param value the property value as a string
 
@@ -264,9 +268,19 @@ GCU_PROP_BOND_TYPE and calls gcu::Bond::SetProperty() for other properties.
 */
 	bool SetProperty (unsigned property, char const *value);
 
+/*!
+@param x the x coordinate to adjust
+@param y the y coordinate to adjust
+
+On entering coordinates are considered relative to the bond axis. This method
+adjust them so that they are put farer from the bond taking line width or
+multiple bonds line into account.
+*/
+	void AdjustPosition (double &x, double &y);
+
 private:
-	GnomeCanvasPathDef* BuildPathDef (WidgetData* pData);
-	GnomeCanvasPathDef* BuildCrossingPathDef (WidgetData* pData);
+//	GnomeCanvasPathDef* BuildPathDef (WidgetData* pData);
+//	GnomeCanvasPathDef* BuildCrossingPathDef (WidgetData* pData);
 	BondType m_type;
 	double m_coords[16];//coordinates of the lines used to represent the bond in the canvas
 	bool m_CoordsCalc; //true if m_coords have been calculated, false else
