@@ -47,6 +47,7 @@ Tool::Tool (Application *App, string Id)
 	m_bChanged = m_bPressed = false;
 	m_pData = NULL;
 	m_OwnStatus = false;
+	m_nState = 0;
 }
 
 Tool::~Tool ()
@@ -142,7 +143,7 @@ bool Tool::Activate (bool bState)
 		return true;
 	} else {
 		if (Deactivate ()) {
-			if (m_pWidget)
+			if (GTK_IS_WIDGET (m_pWidget))
 				gdk_window_set_cursor (gtk_widget_get_parent_window (m_pWidget), NULL);
 			m_pObject = NULL;
 			m_pWidget = NULL;
