@@ -4,7 +4,7 @@
  * GChemPaint library
  * view.cc
  *
- * Copyright (C) 2001-2009 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -166,14 +166,16 @@ GtkWidget* View::CreateNewWidget ()
 void View::OnDestroy (GtkWidget* widget)
 {
 	if (m_bEmbedded) {
-		delete (WidgetData*) g_object_get_data (G_OBJECT (widget), "data");
 		m_Widgets.remove (widget);
 	} else
 		delete m_pDoc;
+	delete (WidgetData*) g_object_get_data (G_OBJECT (widget), "data");
 }
 
 void View::Update (Object *pObject)
 {
+	if (!m_pWidget)
+		return;
 	gccv::ItemClient *client = dynamic_cast <gccv::ItemClient *> (pObject);
 	if (client)
 		client->UpdateItem ();
@@ -608,7 +610,7 @@ bool View::OnKeyPress (GtkWidget* w, GdkEventKey* event)
 			map<string, Element*>::iterator i, end = entries.end ();
 			g_object_unref (m_UIManager);
 			m_UIManager = gtk_ui_manager_new ();
-			GtkActionGroup *group = gtk_action_group_new ("element");;
+			GtkActionGroup *group = gtk_action_group_new ("element");
 			GtkAction *action;
 			string ui;
 			for (i = entries.begin (); i != end; i++) {
