@@ -4,7 +4,7 @@
  * GChemPaint selection plugin
  * erasertool.cc
  *
- * Copyright (C) 2001-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -24,12 +24,17 @@
 
 #include "config.h"
 #include "erasertool.h"
-#include <gcp/settings.h>
-#include <gcp/document.h>
 #include <gcp/atom.h>
 #include <gcp/bond.h>
+#include <gcp/document.h>
 #include <gcp/fragment.h>
+#include <gcp/settings.h>
 #include <gcp/theme.h>
+#include <gcp/view.h>
+#include <gcp/widgetdata.h>
+#include <gccv/canvas.h>
+#include <gccv/item.h>
+#include <gccv/item-client.h>
 #include <cmath>
 
 using namespace gcu;
@@ -45,22 +50,26 @@ gcpEraserTool::~gcpEraserTool ()
 
 bool gcpEraserTool::OnClicked ()
 {
+	m_pData->UnselectAll ();
 	if (m_pObject) {
 		if (m_pObject->IsLocked ())
 			return false;
 		TypeId Id = m_pObject->GetType ();
 		if (Id == ReactionOperatorType)
 			return false; //It's an automatic object, don't delete it
-		m_pObject->SetSelected (m_pWidget, gcp::SelStateErasing);
-		m_pItem = m_pView->GetCanvasItem (m_pWidget, m_pObject);
+		gccv::ItemClient *client = dynamic_cast <gccv::ItemClient *> (m_pObject);
+		if (client) {
+			client->SetSelected (gcp::SelStateErasing);
+			m_Item = client->GetItem ();
+		}
 		if (Id == AtomType) {
 			Object* parent = m_pObject->GetParent ();
 			if (parent->GetType () == FragmentType)
-				m_pItem = m_pView->GetCanvasItem (m_pWidget, parent);
+				m_Item = dynamic_cast <gccv::ItemClient *> (parent)->GetItem ();
 			std::map<Atom*, Bond*>::iterator i;
 			gcp::Bond* pBond = (gcp::Bond*)((gcp::Atom*)m_pObject)->GetFirstBond (i);
 			while (pBond) {
-				pBond->SetSelected (m_pWidget, gcp::SelStateErasing);
+				pBond->SetSelected (gcp::SelStateErasing);
 				pBond = (gcp::Bond*) ((gcp::Atom*) m_pObject)->GetNextBond (i);
 			}
 		}
@@ -75,26 +84,27 @@ void gcpEraserTool::OnDrag ()
 	if (!m_pObject)
 		return;
 	TypeId Id = m_pObject->GetType ();
-	GnomeCanvasItem* pItem = gnome_canvas_get_item_at (GNOME_CANVAS (m_pWidget), m_x, m_y);
+	gccv::Item *pItem = m_pView->GetCanvas ()->GetItemAt (m_x, m_y);
 	gcp::Theme *Theme = m_pView->GetDoc ()->GetTheme ();
 	Object* pObject = NULL;
+	gccv::ItemClient *client = dynamic_cast <gccv::ItemClient *> (m_pObject);
 	switch (Id) {
 	case BondType:
 		if (((gcp::Bond*) m_pObject)->GetDist (m_x / m_dZoomFactor, m_y / m_dZoomFactor) < (Theme->GetPadding () + Theme->GetBondWidth () / 2) / m_dZoomFactor) {
 			if (!m_bChanged) {
-				m_pObject->SetSelected (m_pWidget, gcp::SelStateErasing);
+				client->SetSelected (gcp::SelStateErasing);
 				m_bChanged = true;
 			}
 		} else if (m_bChanged) {
-			m_pObject->SetSelected (m_pWidget, gcp::SelStateUnselected);
+			client->SetSelected (gcp::SelStateUnselected);
 			m_bChanged = false;
 		}
 		break;
 	case AtomType:
-		if (pItem == (GnomeCanvasItem*) m_pBackground)
-			pItem = NULL;
-		if (pItem)
-			pObject = (Object*) g_object_get_data (G_OBJECT (pItem), "object");
+		if (pItem) {
+			gccv::ItemClient *cli = pItem->GetClient ();
+			pObject = (cli)? dynamic_cast <Object *> (cli): NULL;
+		}
 		if (pObject) {
 			if (pObject->GetType () == BondType)
 				pObject = ((gcp::Bond*) pObject)->GetAtomAt (m_x / m_dZoomFactor, m_y / m_dZoomFactor);
@@ -103,36 +113,38 @@ void gcpEraserTool::OnDrag ()
 		}
 		if (pObject == m_pObject) {
 			if (!m_bChanged) {
-				m_pObject->SetSelected (m_pWidget, gcp::SelStateErasing);
+				client->SetSelected (gcp::SelStateErasing);
 				std::map<Atom*, Bond*>::iterator i;
 				gcp::Bond* pBond = (gcp::Bond*) ((gcp::Atom*) m_pObject)->GetFirstBond (i);
 				while (pBond) {
-					pBond->SetSelected (m_pWidget, gcp::SelStateErasing);
+					pBond->SetSelected (gcp::SelStateErasing);
 					pBond = (gcp::Bond*) ((gcp::Atom*) m_pObject)->GetNextBond (i);
 				}
 				m_bChanged = true;
 			}
 		} else if (m_bChanged) {
-			m_pObject->SetSelected (m_pWidget, gcp::SelStateUnselected);
+			client->SetSelected (gcp::SelStateUnselected);
 			std::map<Atom*, Bond*>::iterator i;
 			gcp::Bond* pBond = (gcp::Bond*) ((gcp::Atom*) m_pObject)->GetFirstBond (i);
 			while (pBond) {
-				pBond->SetSelected (m_pWidget, gcp::SelStateUnselected);
+				pBond->SetSelected (gcp::SelStateUnselected);
 				pBond = (gcp::Bond*) ((gcp::Atom*) m_pObject)->GetNextBond (i);
 			}
 			m_bChanged = false;
 		}
 		break;
 	default:
-		if (pItem)
-			pObject = (Object*) g_object_get_data (G_OBJECT (pItem), "object");
+		if (pItem) {
+			gccv::ItemClient *cli = pItem->GetClient ();
+			pObject = (cli)? dynamic_cast <Object *> (cli): NULL;
+		}
 		if (pObject == m_pObject) {
 			if (!m_bChanged) {
-				m_pObject->SetSelected (m_pWidget, gcp::SelStateErasing);
+				client->SetSelected (gcp::SelStateErasing);
 				m_bChanged = true;
 			}
 		} else if (m_bChanged) {
-			m_pObject->SetSelected (m_pWidget, gcp::SelStateUnselected);
+			client->SetSelected (gcp::SelStateUnselected);
 			m_bChanged = false;
 		}
 	}
@@ -142,13 +154,19 @@ void gcpEraserTool::OnRelease ()
 {
 	char *id = NULL;
 	if ((!m_pObject) || (!m_bChanged)) {
-		m_pItem = NULL;
+		m_Item = NULL;
 		return;
 	}
 	gcp::Document* pDoc = m_pView->GetDoc ();
 	gcp::Operation *pOp;
 	Object *pObj = m_pObject->GetGroup (), *Parent;
-	if (pObj && (pObj->GetType () != MoleculeType || m_pObject->GetType () == OtherType)) {
+	if (m_pObject->GetType () == AtomType) {
+		Object* parent = m_pObject->GetParent ();
+		if (parent->GetType () == FragmentType)
+			m_pObject = parent;
+	}
+	Parent = m_pObject->GetParent ();
+	if (pObj && (pObj->GetType () != MoleculeType || Parent->GetType () == AtomType)) {
 		pOp = pDoc->GetNewOperation (gcp::GCP_MODIFY_OPERATION);
 		pOp->AddObject (pObj, 0);
 		id = g_strdup (pObj->GetId ());
@@ -156,20 +174,10 @@ void gcpEraserTool::OnRelease ()
 		pOp = pDoc->GetNewOperation (gcp::GCP_DELETE_OPERATION);
 		pOp->AddObject (m_pObject);
 	}
-	if (m_pObject->GetType () == AtomType) {
-		Object* parent = m_pObject->GetParent ();
-		if (parent->GetType () == FragmentType)
-			m_pObject = parent;
-	}
-	Parent = m_pObject->GetParent ();
 // A molecule might disappear, so get its parent
 	if (Parent->GetType () == MoleculeType)
 		Parent = Parent->GetParent ();
-	m_pItem = NULL;
-	if (m_pData->Items[m_pObject] == NULL) {
-		m_pData->Items.erase (m_pObject);
-		return;
-	}
+	m_Item = NULL;
 	pDoc->Remove (m_pObject);
 	Parent->EmitSignal (gcp::OnChangedSignal);
 	if (id) {
@@ -180,3 +188,29 @@ void gcpEraserTool::OnRelease ()
 	}
 	pDoc->FinishOperation ();
 }
+
+void gcpEraserTool::OnMotion ()
+{
+	m_pData->UnselectAll ();
+	if (m_pObject) {
+		if (m_pObject->IsLocked ())
+			return;
+		TypeId Id = m_pObject->GetType ();
+		if (Id == ReactionOperatorType)
+			return; //It's an automatic object, can't be deleted
+		m_pData->SetSelected (m_pObject, gcp::SelStateErasing);
+		if (Id == AtomType) {
+			std::map<Atom*, Bond*>::iterator i;
+			gcp::Bond* pBond = (gcp::Bond*)((gcp::Atom*)m_pObject)->GetFirstBond (i);
+			while (pBond) {
+				m_pData->SetSelected (pBond, gcp::SelStateErasing);
+				pBond = (gcp::Bond*) ((gcp::Atom*) m_pObject)->GetNextBond (i);
+			}
+		}
+	}
+}
+
+void gcpEraserTool::OnLeaveNotify ()
+{
+	m_pData->UnselectAll ();
+}
