@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -34,11 +34,12 @@ using namespace gcu;
 
 class gcCellDlg: public Dialog
 {
+friend class gcCellDlgPrivate;
 public:
 	gcCellDlg (gcApplication *App, gcDocument* pDoc);
 	virtual ~gcCellDlg ();
 	
-	virtual bool Apply ();
+	bool Apply ();
 	void OnTypeChanged ();
 	
 private:
@@ -47,6 +48,10 @@ private:
 	gdouble m_a, m_b, m_c, m_alpha, m_beta, m_gamma;
 	GtkComboBox* TypeMenu;
 	GtkEntry *A, *B, *C, *Alpha, *Beta, *Gamma;
+	GtkToggleButton *AutoSpaceGroup;
+	GtkSpinButton *SpaceGroup;
+	GtkAdjustment *SpaceGroupAdj;
+	unsigned SpaceGroupSignal, TypeSignal;
 };
 
 #endif //GCRYSTAL_CELLDLG_H
