@@ -191,7 +191,7 @@ static GtkActionEntry entries[] = {
 		  N_("Create an melting temperature chart"), G_CALLBACK (on_chart) },
       { "bp", NULL, N_("Ebullition temperature"), NULL,
 		  N_("Create an ebullition temperature chart"), G_CALLBACK (on_chart) },
-	  { "CustomChart", NULL, N_("Custom "), NULL,
+	  { "CustomChart", NULL, N_("Custom"), NULL,
 		  N_("Create a custom chart"), G_CALLBACK (on_new_chart) },
   { "HelpMenu", NULL, N_("_Help"), NULL, NULL, NULL },
 	  { "Help", GTK_STOCK_HELP, N_("_Contents"), "F1",
@@ -338,6 +338,7 @@ GChemTableApp::GChemTableApp (): Application ("gchemtable")
 	gtk_box_pack_end (GTK_BOX(vbox), GTK_WIDGET(GCU_PERIODIC(periodic)), true, true, 0);
 	gtk_container_add(GTK_CONTAINER(window), GTK_WIDGET(vbox));
 	gtk_widget_show_all(window);
+	g_object_unref (ui_manager);
 	for (int i = 0; i < 118; i++)
 		Pages[i] = NULL;
 	
@@ -413,14 +414,14 @@ void GChemTableApp::OnAbout ()
 	/* Note to translators: replace the following string with the appropriate credits for you lang */
 	const gchar * translator_credits = _("translator_credits");
 	gtk_show_about_dialog (GetWindow (),
-	                       "name", "GChemTable",
+	                       "program-name", "GChemTable",
 	                       "authors", authors,
 	                       "comments", comments,
 	                       "copyright", copyright,
 	                       "license", license,
 	                       "translator_credits", translator_credits,
 	                       "version", VERSION,
-	                       "website", "http://www.nongnu.org/gchemutils",
+	                       "website", "http://gchemutils.nongnu.org",
 	                       NULL);
 }
 
